#  pygyver

Contains Data Enginner, Data Scientist and 3rd party integration tools capabilities.

## Install
pygyver can be installed via pip

```python 
pip install pygyver
```


## env var required

```
PROJECT_ROOT=  "root of he project"

AWS_ACCESS_KEY_ID=
AWS_SECRET_ACCESS_KEY=
AWS_DEFAULT_REGION=
AWS_S3_BUCKET=
AWS_S3_ROOT=

GOOGLE_APPLICATION_CREDENTIALS="path to the json token file"
BIGQUERY_PROJECT= "default name of the project in BigQuery"

```

## [etl](../master/pygyver/etl/README.md)

## [data_prep](../master/pygyver/data_prep/README.md)


## Pypi release

- create a PR
- ask for code review
- merge to master branch
- create a new Release in https://github.com/madedotcom/pygyver/releases

## Developing locally

```
source load-local-vars.sh --> sets local vars
make build --> build container locally
make run-tests --> executes the tests
```